@@ -37,7 +37,6 @@ class BeeFTPHandler(object):
         self.banner = options['protocol_specific_data']['banner']
         self.max_logins = int(options['protocol_specific_data']['max_attempts'])
         self.syst_type = options['protocol_specific_data']['syst_type']
-        self.curr_logins = 0
         self.authenticated = False
         self.conn = conn
         self.serve_flag = True
@@ -56,6 +55,9 @@ class BeeFTPHandler(object):
         self.client_addr = None  # data connection
         self.client_port = None  #
         self.working_dir = None
+        self.user = None
+        self.cli_ip = None
+        self.cli_port = None
         self.serve()
 
     def serve(self):
@@ -99,16 +101,15 @@ class BeeFTPHandler(object):
         if self.state != 'USER':
             self.respond('503 Login with USER first.')
             return
-        self.curr_logins += 1
-        self.passwd = arg
-        if self.session.try_auth('plaintext', username=self.user, password=self.passwd):
+        passwd = arg
+        if self.session.try_auth('plaintext', username=self.user, password=passwd):
             self.authenticated = True
             self.working_dir = '/'
             self.respond('230 Login Successful.')
         else:
             self.authenticated = False
             self.respond('530 Authentication Failed.')
-            if self.curr_logins >= self.max_logins:
+            if self.session.get_number_of_login_attempts() >= self.max_logins:
                 self.stop()
 
     def do_PORT(self, arg):
@@ -213,15 +214,17 @@ class BeeFTPHandler(object):
         self.conn.send(msg)
 
     def stop(self):
-        self.conn.close()
-        self.session.connected = False
+        self.session.end_session()
 
 
 class ftp(HandlerBase):
-    def __init__(self, sessions, options, work_dir):
-        super(ftp, self).__init__(sessions, options, work_dir)
+    def __init__(self, options, work_dir):
+        super(ftp, self).__init__(options, work_dir)
         self._options = options
 
     def handle_session(self, gsocket, address):
         session = self.create_session(address)
-        BeeFTPHandler(gsocket, session, self.vfsystem.opendir('/pub/ftp'), self._options)
\ No newline at end of file
+        try:
+            BeeFTPHandler(gsocket, session, self.vfsystem.opendir('/pub/ftp'), self._options)
+        finally:
+            self.close_session(session)
\ No newline at end of file
