@@ -84,8 +84,8 @@ class Honeypot(object):
                 certfile.write(cert)
             with open(key_path, 'w') as keyfile:
                 keyfile.write(priv_key)
-            send_zmq_push(SocketNames.SERVER_RELAY, '{0} {1} {2}'.format(Messages.KEY, self.id, keyfile))
-            send_zmq_push(SocketNames.SERVER_RELAY, '{0} {1} {2}'.format(Messages.CERT, self.id, cert))
+            send_zmq_push(SocketNames.SERVER_RELAY.value, '{0} {1} {2}'.format(Messages.KEY.value, self.id, keyfile))
+            send_zmq_push(SocketNames.SERVER_RELAY.value, '{0} {1} {2}'.format(Messages.CERT.value, self.id, cert))
 
         if self.config['general']['fetch_ip']:
             try:
