@@ -39,21 +39,22 @@ class SessionPersister(gevent.Greenlet):
     def __init__(self, max_sessions, clear_sessions=False, delay_seconds=30):
         assert delay_seconds > 1
         Greenlet.__init__(self)
-        self.db_session = database_setup.get_session()
+        db_session = database_setup.get_session()
         # pending session will be converted to attacks if we cannot match with bait traffic
         # with this period
         self.delay_seconds = delay_seconds
         # clear all pending sessions on startup, pending sessions on startup
-        pending_classification = self.db_session.query(Classification).filter(Classification.type == 'pending').one()
-        pending_deleted = self.db_session.query(Session).filter(
+        pending_classification = db_session.query(Classification).filter(Classification.type == 'pending').one()
+        pending_deleted = db_session.query(Session).filter(
             Session.classification == pending_classification).delete()
-        self.db_session.commit()
+        db_session.commit()
         logging.info('Cleaned {0} pending sessions on startup'.format(pending_deleted))
         self.do_classify = False
         if clear_sessions or max_sessions == 0:
-            count = self.db_session.query(Session).delete()
+            db_session = database_setup.get_session()
+            count = db_session.query(Session).delete()
             logging.info('Deleting {0} sessions on startup.'.format(count))
-            self.db_session.commit()
+            db_session.commit()
 
         self.max_session_count = max_sessions
         if max_sessions:
@@ -62,15 +63,15 @@ class SessionPersister(gevent.Greenlet):
         context = beeswarm.shared.zmq_context
 
         self.subscriber_sessions = context.socket(zmq.SUB)
-        self.subscriber_sessions.connect(SocketNames.RAW_SESSIONS)
-        self.subscriber_sessions.setsockopt(zmq.SUBSCRIBE, Messages.SESSION_CLIENT)
-        self.subscriber_sessions.setsockopt(zmq.SUBSCRIBE, Messages.SESSION_HONEYPOT)
+        self.subscriber_sessions.connect(SocketNames.RAW_SESSIONS.value)
+        self.subscriber_sessions.setsockopt(zmq.SUBSCRIBE, Messages.SESSION_CLIENT.value)
+        self.subscriber_sessions.setsockopt(zmq.SUBSCRIBE, Messages.SESSION_HONEYPOT.value)
 
         self.processedSessionsPublisher = context.socket(zmq.PUB)
-        self.processedSessionsPublisher.bind(SocketNames.PROCESSED_SESSIONS)
+        self.processedSessionsPublisher.bind(SocketNames.PROCESSED_SESSIONS.value)
 
         self.config_actor_socket = context.socket(zmq.REQ)
-        self.config_actor_socket.connect(SocketNames.CONFIG_COMMANDS)
+        self.config_actor_socket.connect(SocketNames.CONFIG_COMMANDS.value)
 
     def _run(self):
         poller = zmq.Poller()
@@ -96,7 +97,7 @@ class SessionPersister(gevent.Greenlet):
             self.do_classify = True
 
     def persist_session(self, session_json, session_type):
-        db_session = self.db_session
+        db_session = database_setup.get_session()
 
         if self.max_session_count == 0:
             return
@@ -110,13 +111,11 @@ class SessionPersister(gevent.Greenlet):
             data = json.loads(unicode(session_json, "ISO-8859-1"))
         logger.debug('Persisting {0} session: {1}'.format(session_type, data))
 
-        db_session = self.db_session
         classification = db_session.query(Classification).filter(Classification.type == 'pending').one()
 
         assert data['honeypot_id'] is not None
         _honeypot = db_session.query(Honeypot).filter(Honeypot.id == data['honeypot_id']).one()
-
-        if session_type == Messages.SESSION_HONEYPOT:
+        if session_type == Messages.SESSION_HONEYPOT.value:
             session = Session()
             for entry in data['transcript']:
                 transcript_timestamp = datetime.strptime(entry['timestamp'], '%Y-%m-%dT%H:%M:%S.%f')
@@ -127,8 +126,8 @@ class SessionPersister(gevent.Greenlet):
             for auth in data['login_attempts']:
                 authentication = self.extract_auth_entity(auth)
                 session.authentication.append(authentication)
-        elif session_type == Messages.SESSION_CLIENT:
-            ignore_failed_bait_sessions = self.send_config_request('{0} {1}'.format(Messages.GET_CONFIG_ITEM,
+        elif session_type == Messages.SESSION_CLIENT.value:
+            ignore_failed_bait_sessions = self.send_config_request('{0} {1}'.format(Messages.GET_CONFIG_ITEM.value,
                                                                                     'ignore_failed_bait_session'))
             if not data['did_complete'] and ignore_failed_bait_sessions:
                 logger.debug('Ignore failed bait session.')
@@ -146,7 +145,6 @@ class SessionPersister(gevent.Greenlet):
         else:
             logger.warn('Unknown message type: {0}'.format(session_type))
             return
-
         session.id = data['id']
         session.classification = classification
         session.timestamp = datetime.strptime(data['timestamp'], '%Y-%m-%dT%H:%M:%S.%f')
@@ -160,12 +158,11 @@ class SessionPersister(gevent.Greenlet):
 
         db_session.add(session)
         db_session.commit()
-
         matching_session = self.get_matching_session(session, db_session)
-        if session_type == Messages.SESSION_HONEYPOT:
+        if session_type == Messages.SESSION_HONEYPOT.value:
             if matching_session:
                 self.merge_bait_and_session(session, matching_session, db_session)
-        elif session_type == Messages.SESSION_CLIENT:
+        elif session_type == Messages.SESSION_CLIENT.value:
             if matching_session:
                 self.merge_bait_and_session(matching_session, session, db_session)
         else:
@@ -190,7 +187,7 @@ class SessionPersister(gevent.Greenlet):
         db_session = db_session
         min_datetime = session.timestamp - timedelta(seconds=timediff)
         max_datetime = session.timestamp + timedelta(seconds=timediff)
-
+        logger.debug('Session dist: {0}'.format(session.discriminator))
         # default return value
         match = None
         classification = db_session.query(Classification).filter(Classification.type == 'pending').one()
@@ -201,12 +198,13 @@ class SessionPersister(gevent.Greenlet):
             .filter(Session.timestamp >= min_datetime) \
             .filter(Session.timestamp <= max_datetime) \
             .filter(Session.id != session.id) \
-            .filter(Session.classification == classification) \
-            .filter(Session.discriminator != session.discriminator)
+            .filter(Session.classification == classification)
 
         # identify the correct session by comparing authentication.
         # this could properly also be done using some fancy ORM/SQL construct.
         for potential_match in sessions:
+            if potential_match.discriminator == session.discriminator:
+                continue
             assert potential_match.id != session.id
             for honey_auth in session.authentication:
                 for session_auth in potential_match.authentication:
@@ -232,9 +230,9 @@ class SessionPersister(gevent.Greenlet):
         db_session.add(bait_session)
         db_session.delete(honeypot_session)
         db_session.commit()
-        self.processedSessionsPublisher.send('{0} {1} {2}'.format(Messages.DELETED_DUE_TO_MERGE, honeypot_session.id,
+        self.processedSessionsPublisher.send('{0} {1} {2}'.format(Messages.DELETED_DUE_TO_MERGE.value, honeypot_session.id,
                                                                   bait_session.id))
-        self.processedSessionsPublisher.send('{0} {1}'.format(Messages.SESSION,
+        self.processedSessionsPublisher.send('{0} {1}'.format(Messages.SESSION.value,
                                                               json.dumps(bait_session.to_dict())))
 
     def classify_malicious_sessions(self):
@@ -245,7 +243,7 @@ class SessionPersister(gevent.Greenlet):
         """
         min_datetime = datetime.utcnow() - timedelta(seconds=self.delay_seconds)
 
-        db_session = self.db_session
+        db_session = database_setup.get_session()
 
         # find and process bait sessions that did not get classified during persistence.
         bait_sessions = db_session.query(BaitSession).options(joinedload(BaitSession.authentication)) \
@@ -256,6 +254,7 @@ class SessionPersister(gevent.Greenlet):
         for bait_session in bait_sessions:
             logger.debug('Classifying bait session with id {0} as MITM'.format(bait_session.id))
             bait_session.classification = db_session.query(Classification).filter(Classification.type == 'mitm').one()
+            db_session.commit()
 
         # find and process honeypot sessions that did not get classified during persistence.
         sessions = db_session.query(Session).filter(Session.discriminator == None) \
@@ -286,7 +285,7 @@ class SessionPersister(gevent.Greenlet):
                 session.classification = db_session.query(Classification).filter(
                     Classification.type == 'bruteforce').one()
             db_session.commit()
-            self.processedSessionsPublisher.send('{0} {1}'.format(Messages.SESSION, json.dumps(session.to_dict())))
+            self.processedSessionsPublisher.send('{0} {1}'.format(Messages.SESSION.value, json.dumps(session.to_dict())))
 
     def send_config_request(self, request):
         return send_zmq_request_socket(self.config_actor_socket, request)
