@@ -17,7 +17,13 @@ class Messages(Enum):
     KEY = 'KEY'
     # CERT DRONE_ID DRONE_CERT
     CERT = 'CERT'
+
+    # All data on an entire session, this also indicates session end.
     SESSION_HONEYPOT = 'SESSION_HONEYPOT'
+    # Network connect to a honeypot, data format is as in SESSION_HONEYPOT, but not all fields has data.
+    SESSION_PART_HONEYPOT_SESSION_START = 'SESSION_PART_HONEYPOT_SESSION_START'
+    # Authentication attempt, format is as in self.login_attempts list SESSION_HONEYPOT
+    SESSION_PART_HONEYPOT_AUTH = 'SESSION_PART_HONEYPOT_AUTH'
     SESSION_CLIENT = 'SESSION_CLIENT'
     SET_CONFIG_ITEM = 'SET'
     GET_CONFIG_ITEM = 'GET'
@@ -33,7 +39,7 @@ class Messages(Enum):
     DRONE_DELETE = 'DRONE_DELETE'
     DRONE_ADD = 'DRONE_ADD'
 
-    # Session was deleted because it was matched with an existing sesisons
+    # Session was deleted because it was matched with an existing session
     # This happens when a bait session is matched with a honeypot session.
     # ID_OF_DELETED_SESSION ID_OF_THE_MERGED_SESSION
     DELETED_DUE_TO_MERGE = "DELETED_DUE_TO_MERGE"
